require 'date'
require 'citypay_api_client/models/api_key'

describe 'ApiKey' do
  before do
    @instance = CityPayApiClient::ApiKey.new(client_id: "PC2", licence_key: "7G79TG62BAJTK669")
  end

  describe 'test generation' do
    it 'should generate a new api key based on algorithm' do
      expect(@instance).to be_instance_of(CityPayApiClient::ApiKey)
      @instance.nonce = "acb875aef083de292299bd69fcdeb5c5"
      @instance.datetime = DateTime.new(2020, 1, 1, 9, 23, 12, 0)
      @instance.generate.should eq("UEMyOkFDQjg3NUFFRjA4M0RFMjkyMjk5QkQ2OUZDREVCNUM1Ol6Q3tCMPsYvqNhFelRD2zQHYlZquBGCY/6ZpZ0AngTF")
    end
  end


  describe 'generate from initialize' do

    it 'should generate a new key' do
      @instance.generate
    end

  end

  describe('standard generation validation') do

    #noinspection RubyLiteralArrayInspection
    data = [
        ["aP","0FLSuYlRk5lLFK46","0172D48B3E020EB68CB177DC4BE537E6","2020-08-01T23:04:23","YVA6MDE3MkQ0OEIzRTAyMEVCNjhDQjE3N0RDNEJFNTM3RTY6mSUTOBc1Y4xSorAZUMtOZWD4vN0ZwAbn77+v+Z5Jbco="],
        ["6oh","IhitVGHjw8WIkafD","C50C8B11123AC2F9B04399EE02EDB7FA","2020-07-14T06:04:10","Nm9oOkM1MEM4QjExMTIzQUMyRjlCMDQzOTlFRTAyRURCN0ZBOo7kVI+jynP7HV1lxO6LopvJJaUVzTxeGu7PCOWvFLFw"],
        ["ZLM","qwHq9BS0vOW1ian5","E571174876229B467CCFCED5648DFB4B","2020-06-25T13:03:57","WkxNOkU1NzExNzQ4NzYyMjlCNDY3Q0NGQ0VENTY0OERGQjRCOsQAA3LtdHidGqrAEf39rLCSLBMB74uX+IWjKiSL/Fry"],
        ["JAnSB","CGqRnPns7rDuNyK7","F58B52303248328766B800021E3AAC32","2020-06-06T20:03:44","SkFuU0I6RjU4QjUyMzAzMjQ4MzI4NzY2QjgwMDAyMUUzQUFDMzI69S5jD67gT/aL8K/9mIH9ZvcznC91iVFK1i1QL/RSZGY="],
        ["9CYH","YIwtokm5HJX4HRyW","A149441E8633C07BBEA44E98064207F4","2020-05-19T03:03:31","OUNZSDpBMTQ5NDQxRTg2MzNDMDdCQkVBNDRFOTgwNjQyMDdGNDrbGQt+S7L28X4tzA5M5c8uuKDlE19po3s0KcT9U07+xA=="],
        ["ntF","QyNlLl5E0VI8yZFW","FBD4F6E51F021FD6FFB84B7A5394F1EE","2020-04-30T10:03:18","bnRGOkZCRDRGNkU1MUYwMjFGRDZGRkI4NEI3QTUzOTRGMUVFOlOnNTEul+L2da3PG6Do4JKuWy/14no8gdQ/Yn0O+Bgp"],
        ["5G","Ij2sltQQIxrX9JNh","B5230BAC144AF5DECBC7FF1DA5FBFD36","2020-04-11T17:03:05","NUc6QjUyMzBCQUMxNDRBRjVERUNCQzdGRjFEQTVGQkZEMzY6YGoTAbvDq8gpui9SgRwBxXkEGjRfP69WfozTBi+51pE="],
        ["kpGivRFGP","kAfYfNsW3g8RN3LE","DF2CC2B598AAABA7237166A0CD18695F","2020-03-24T00:02:52","a3BHaXZSRkdQOkRGMkNDMkI1OThBQUFCQTcyMzcxNjZBMENEMTg2OTVGOjUgfRSOU2IpTYmogi6M6NG4p2l3FKDZUrnLQx+bA1ag"],
        ["sw7Ue9gDC","D8cSOeuiVbLlKkAm","642FD45F8CFBC8CB8C340F96131B80E9","2020-03-05T07:02:39","c3c3VWU5Z0RDOjY0MkZENDVGOENGQkM4Q0I4QzM0MEY5NjEzMUI4MEU5Oj1yc6kNtdZWQrwAhIGgKg2+MfM1cy4LloYD39NWfOms"],
        ["mYCWPXSx8","eDsEdnL9Ic4AJKve","7129F032ABC0C0038A5DE2CD61DC0435","2020-02-15T14:02:26","bVlDV1BYU3g4OjcxMjlGMDMyQUJDMEMwMDM4QTVERTJDRDYxREMwNDM1Ovsnt3Dzh8e5n9CpiZX8PSJ4JqtajRGDZUIAxZxAoynr"],
        ["lmtv9HsWI","JOt5dH41lMrSUZJi","5BE9868B5F42C61B986BD3D654BF6613","2020-01-27T21:02:13","bG10djlIc1dJOjVCRTk4NjhCNUY0MkM2MUI5ODZCRDNENjU0QkY2NjEzOoUAiGITnda4EB2YHx/8zGP3FBgIHYkVU0d3PKYk3Paj"],
        ["ANWG7Vm0M","nCg3HeqhaDps6TZW","D3CF885E78D029AFFF6556B671EA5218","2020-01-09T04:02","QU5XRzdWbTBNOkQzQ0Y4ODVFNzhEMDI5QUZGRjY1NTZCNjcxRUE1MjE4OsBwvBUChvSNpwfUDhiojDldWGSi/X4/TyEIlWH7sf4m"],
        ["8M9drxQ8S","SfHLDlkF3ITHumKP","32948557E8846D6D50405510EB6361EF","2019-12-21T11:01:47","OE05ZHJ4UThTOjMyOTQ4NTU3RTg4NDZENkQ1MDQwNTUxMEVCNjM2MUVGOnGfxF1TmrtTGXr7wBlnhlvfcUCPHQnuvPsQNh+2iXt9"],
        ["PeA2oninT","xqs5MiXQMAq9vkO3","48D1E13E27C7CDA944465B53AF0215C2","2019-12-02T18:01:34","UGVBMm9uaW5UOjQ4RDFFMTNFMjdDN0NEQTk0NDQ2NUI1M0FGMDIxNUMyOugLjVkPR/iaRizSSFnAA01h8Ta7qlPf57K8wRx27FGC"],
        ["HDrdtwL2N","4WvdGVEj1d3eguPJ","0FD35319FEF366A019971715703122E1","2019-11-14T01:01:21","SERyZHR3TDJOOjBGRDM1MzE5RkVGMzY2QTAxOTk3MTcxNTcwMzEyMkUxOkgBNqCfcWnlSP1MtmULpRVm4RbVY+gAaIKx6wTNKwZS"],
        ["IvNuNrAns","KTodzmawZlql3lwt","6B315F760CF4F1503FCD697DE6F7707F","2019-10-26T08:01:08","SXZOdU5yQW5zOjZCMzE1Rjc2MENGNEYxNTAzRkNENjk3REU2Rjc3MDdGOlTnuUcLSpMVtK6a10hrQBeornjKy7KwPA/I3h20FsYt"],
        ["5e0V6iMOr","vsVvLLOTQcQWfuPe","1F3E63C31ADBDEB3F5C922CCA3895CD8","2019-10-07T15:00:55","NWUwVjZpTU9yOjFGM0U2M0MzMUFEQkRFQjNGNUM5MjJDQ0EzODk1Q0Q4Osl239n0tQLwq3MgzdqJmqqySMRYcx6rbG6vw2+I8B1h"],
        ["Zw6vcdEB6","MvjxOH6gDF8cByud","91B4FE721B9E39C5B078687541D01A8F","2019-09-18T22:00:42","Wnc2dmNkRUI2OjkxQjRGRTcyMUI5RTM5QzVCMDc4Njg3NTQxRDAxQThGOji6+2vTwoR8OjrMpbJ9VY+HrDlRk7BXe1zJAWZxoR3m"],
        ["v26Otxsyz","iUltF2cHM8kwBOxO","F33A3AAA272685E583E542C363D5FD96","2019-08-31T05:00:29","djI2T3R4c3l6OkYzM0EzQUFBMjcyNjg1RTU4M0U1NDJDMzYzRDVGRDk2Og1NJjSdJec/W0HdPkFPY8reYq3eK2ow3fEmPmwKKeJg"],
        ["SgnphnJP6","zgV5VlZL2zDGEHyG","FC08F615D14E4396DBB63EB87E6DBD91","2019-08-12T12:00:16","U2ducGhuSlA2OkZDMDhGNjE1RDE0RTQzOTZEQkI2M0VCODdFNkRCRDkxOnta4KFmRnx/yxxMSEYauBN8YwG/rDdJS7UOiLRY+n8t"],
        ["G7kd2YHP2","W5WP1tbKYu1o9dqS","3FAA3261E9EED86070F2C99BF3131847","2019-07-24T19:00:03","RzdrZDJZSFAyOjNGQUEzMjYxRTlFRUQ4NjA3MEYyQzk5QkYzMTMxODQ3OggmHx3ty1IlKr+IQnqakqVLYFcLO5wd5EYy0cxVjV/f"],
        ["6Q3WoEfYC","J5gI4aUpHVtA5Suf","EBB8C8905DDB2C4081FAFF20818A73F6","2019-07-06T01:59:50","NlEzV29FZllDOkVCQjhDODkwNUREQjJDNDA4MUZBRkYyMDgxOEE3M0Y2OnTpx4Gc8B6UHpRxxmZuLmCmWn1dbuPL6NeFV8pxN31v"],
        ["auijI3nyS","OU4Z7Svh7hKZImXX","6DE371427723FF6CE9D604925C610333","2019-06-17T08:59:37","YXVpakkzbnlTOjZERTM3MTQyNzcyM0ZGNkNFOUQ2MDQ5MjVDNjEwMzMzOiE83C7NO90jyE0Rpo9Kb0UuMoEcUuUZRtULazrvzBKP"],
        ["94JCLlSzp","fkKMaZlisNWEQzJ7","F9929A12E86121D75BD40B6F9D0A7783","2019-05-29T15:59:24","OTRKQ0xsU3pwOkY5OTI5QTEyRTg2MTIxRDc1QkQ0MEI2RjlEMEE3NzgzOoioe2F/SEDYMU1RRqAph8+xpOomlct3PtqT0GsZdEeO"],
        ["7y2nWixPc","Z4U3Ly0yls1Bygkd","213E32F0F98BF6AA9F5C201B3F1683C8","2019-05-10T22:59:11","N3kybldpeFBjOjIxM0UzMkYwRjk4QkY2QUE5RjVDMjAxQjNGMTY4M0M4OrWF87svGfZJdQyXuUQqrdS0+Y27qiHuub0eqg5J3IQ5"],
        ["IN4k12HJz","EmBqZaOktTC4vVJE","257FA0020CC89727D1996053EC48D427","2019-04-22T05:58:58","SU40azEySEp6OjI1N0ZBMDAyMENDODk3MjdEMTk5NjA1M0VDNDhENDI3OsO/hAllOkfhZOr7tZop8Z8FRFQeqL8eqJ2GGjs7M2qQ"],
        ["G60QusAjJ","VVazjlgrgGxqV1Np","EEA45C78A28B2849270EA1E67BC22BBF","2019-04-03T12:58:45","RzYwUXVzQWpKOkVFQTQ1Qzc4QTI4QjI4NDkyNzBFQTFFNjdCQzIyQkJGOi/RQgaWXQqYs9GHh5oSy+WkC3Pzwzgu0Ua+vlHxqLni"],
        ["pgM3vQwvZ","XcIF5R7tMbsOu3fs","5FFE3AD3D912F75CEFD5BBBDF51DA8FD","2019-03-15T19:58:32","cGdNM3ZRd3ZaOjVGRkUzQUQzRDkxMkY3NUNFRkQ1QkJCREY1MURBOEZEOhNlEQUDcGsIgQtObT5I/ZCuK9DrVjX4sytrn43JfefS"],
        ["gX1zl94d8","ycvUWcoU6FnWptVZ","3FBD83CDFDBC53B89F8E9C101DC52577","2019-02-25T02:58:19","Z1gxemw5NGQ4OjNGQkQ4M0NERkRCQzUzQjg5RjhFOUMxMDFEQzUyNTc3OkkeurytcvmHh6JlmPx1TxorZ4mka6XhJzgO91Wbx1q9"],
        ["ncicPapCa","ZpsDUzIZzAeLHgIJ","019B54A4AFC5E4C7187BC863871BA98C","2019-02-06T09:58:06","bmNpY1BhcENhOjAxOUI1NEE0QUZDNUU0QzcxODdCQzg2Mzg3MUJBOThDOmJIPoiFJj3rDuRyUoGu87DBqDpYWsMxNSbT1Z5PZ9Np"],
        ["2VCCeWYII","1NpLprJI4EXPr7lw","034931F44CFAD6072B5D69972E10E934","2019-01-18T16:57:53","MlZDQ2VXWUlJOjAzNDkzMUY0NENGQUQ2MDcyQjVENjk5NzJFMTBFOTM0OvrsfsZhD1VSxwlWKd43QsvuNi5KulQ5JbdCWbgaUL6Z"]
    ]

    data.each_with_index do |item, index|
      it "should test data for item #{index}" do
        expect(item.size).to eq(5)
        key = CityPayApiClient::ApiKey.new(client_id: item[0], licence_key: item[1])
        key.nonce = item[2]
        key.datetime = DateTime.parse(item[3], "%Y-%m-dT%H:%M:%S")
        key.generate.should eq(item[4])
      end
    end


  end


end
